@@ -18,7 +18,7 @@ function(x, cl, train, test, k=1){
  pred <- factor(rep(NA,length(test)), levels=levels(cl))
  
  for(i in 1:length(test)){
-  tmp <- as.integer(which(M[test[i],train] == min(M[test[i],train], na.rm=TRUE)))
+  tmp <- as.integer(order(M[test[i],train]))
   tmp <- tmp[1:min(k,length(tmp))]
 
   if(length(tmp)>1){
